@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-06-19'; # DATE
+our $DATE = '2023-07-21'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.027'; # VERSION
+our $VERSION = '1.028'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -61,6 +61,19 @@ _
 
         quiet => {
             summary => 'If set to true, do not show messages',
+            description => <<'_',
+
+Normally a message will be printed to stdout saying whether the rows are sorted
+or not, i.e. one of:
+
+    Rows are sorted
+    Rows are NOT sorted
+
+If this option is specified, then no message will be printed. Instead, you can
+find out whether things are sorted via exit code (or status code in the
+enveloped result, if you request JSON or call this utility as a Perl function).
+
+_
             schema => 'bool*',
             cmdline_aliases => {q=>{}},
         },
@@ -93,7 +106,7 @@ App::CSVUtils::csv_sorted_rows - Check that CSV rows are sorted
 
 =head1 VERSION
 
-This document describes version 1.027 of App::CSVUtils::csv_sorted_rows (from Perl distribution App-CSVUtils), released on 2023-06-19.
+This document describes version 1.028 of App::CSVUtils::csv_sorted_rows (from Perl distribution App-CSVUtils), released on 2023-07-21.
 
 =head1 FUNCTIONS
 
@@ -236,6 +249,16 @@ argument.
 
 If set to true, do not show messages.
 
+Normally a message will be printed to stdout saying whether the rows are sorted
+or not, i.e. one of:
+
+ Rows are sorted
+ Rows are NOT sorted
+
+If this option is specified, then no message will be printed. Instead, you can
+find out whether things are sorted via exit code (or status code in the
+enveloped result, if you request JSON or call this utility as a Perl function).
+
 =item * B<reverse> => I<bool>
 
 (No description)
